@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,16 +13,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
     Sequence,
     Tuple,
     Optional,
+    Iterator,
 )
 
 from google.cloud.translate_v3.types import translation_service
@@ -76,14 +74,14 @@ class ListGlossariesPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[translation_service.ListGlossariesResponse]:
+    def pages(self) -> Iterator[translation_service.ListGlossariesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[translation_service.Glossary]:
+    def __iter__(self) -> Iterator[translation_service.Glossary]:
         for page in self.pages:
             yield from page.glossaries
 
@@ -117,7 +115,7 @@ class ListGlossariesAsyncPager:
         *,
         metadata: Sequence[Tuple[str, str]] = ()
     ):
-        """Instantiate the pager.
+        """Instantiates the pager.
 
         Args:
             method (Callable): The method that was originally called, and
@@ -138,14 +136,14 @@ class ListGlossariesAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[translation_service.ListGlossariesResponse]:
+    async def pages(self) -> AsyncIterator[translation_service.ListGlossariesResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[translation_service.Glossary]:
+    def __aiter__(self) -> AsyncIterator[translation_service.Glossary]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.glossaries:
