@@ -557,5 +557,8 @@ class TranslationServiceGrpcAsyncIOTransport(TranslationServiceTransport):
             )
         return self._stubs["delete_glossary"]
 
+    def close(self):
+        return self.grpc_channel.close()
+
 
 __all__ = ("TranslationServiceGrpcAsyncIOTransport",)
